@@ -6,8 +6,12 @@ import paramiko
 from qds_ops.utils.fork import Fork
 
 class Knife:
-  def search(__self__, env, tier):
+  def search(__self__, env, tier, extra_filters=None):
     search_string = "chef_environment:%s AND qubole_tier:%s" % (env, tier)
+    if extra_filters is not None:
+      filters = " AND ".join(extra_filters)
+      search_string = "%s AND %s" % (search_string, filters)
+
     output = Fork.check_output(["knife","search","node",search_string,
         "-a","ec2.public_hostname","--format","yaml"], stderr=None)
     nodes = yaml.load(output)
@@ -47,9 +51,12 @@ puts nodeinfo.to_json""" % (env, tier)
     t.close()
     return t.name
 
-  def ssh(self, env, tier, cmd):
+  def ssh(self, cmd, env, tier, extra_filters=None):
     temp = self.get_pemfile(env)
     search_string = "chef_environment:%s AND qubole_tier:%s" % (env, tier)
+    if extra_filters is not None:
+      filters = " AND ".join(extra_filters)
+      search_string = "%s AND %s" % (search_string, filters)
     output = Fork.check_output(["knife","ssh", search_string, cmd, "-x","ec2-user","-i",temp,"-a","ec2.public_hostname"],
         stderr=None)
     os.unlink(temp)
